@@ -289,7 +289,8 @@ class run(TestAffectingCommand):
                 self.args.skip_software_context,
                 self.args.skip_hardware_context,
                 self.args.trusted_time,
-                self.args.analyzer_assigned_uuid)
+                self.args.analyzer_assigned_uuid,
+                test)
         except ImportError as exc:
             msg_template = (
                 "Unable to probe for software context. Install the '%s'"
