@@ -20,13 +20,15 @@ output with a cable.
 **Default options:** None
 """
 
-INSTALLSTEPS = ['git clone git://git.linaro.org/people/kurt-r-taylor/e2eaudiotest.git']
+GIT_REPOS = ['git://git.linaro.org/people/kurt-r-taylor/e2eaudiotest.git']
+
+INSTALLSTEPS = ['cd e2eaudiotest; gcc testfreq.c utils_alsa.c -lasound -lfftw3 -o testfreq ']
 DEPS = ['git-core', 'libasound2-dev', 'libfftw3-dev', 'gcc']
 DEFAULT_OPTIONS = ""
-RUNSTEPS = ['cd e2eaudiotest; gcc testfreq.c utils_alsa.c -lasound -lfftw3 -o testfreq ; ./e2eaudiotest.sh']
+RUNSTEPS = ['cd e2eaudiotest; ./e2eaudiotest.sh']
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<result>\w+)\W+(?P<measurement>\d+)\W+sinewave"
 
-e2einst = TestInstaller(INSTALLSTEPS, deps=DEPS)
+e2einst = TestInstaller(INSTALLSTEPS, deps=DEPS, git_repos=GIT_REPOS)
 e2erun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
 e2eparser = TestParser(PATTERN,
                appendall={'units':'Hz'})
