@@ -27,14 +27,15 @@ from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
 DEFAULT_OPTIONS = ""
-INSTALLSTEPS = ['git clone git://github.com/janimo/firefox-startup-timing.git']
+
+GIT_REPOS = ['git://github.com/janimo/firefox-startup-timing.git']
 DEPS = ['firefox', 'git-core', 'gcalctool']
 RUNSTEPS = [(
     'cd firefox-startup-timing;'
     ' ./firefox_startup_timing.sh $(OPTIONS)')]
 PATTERN = "^(?P<test_case_id>\w+):(?P<measurement>\d+)"
 
-installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
+installer = TestInstaller(deps=DEPS, git_repos=GIT_REPOS)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parser = TestParser(PATTERN, appendall={'units': 'ms', 'result': 'pass'})
 
