@@ -28,14 +28,13 @@ from lava_test.core.tests import Test
 
 DEFAULT_OPTIONS = ""
 
-INSTALLSTEPS = [
-    "apt-get build-dep lttng-tools --yes",
-    "bzr branch lp:~linaro-foundations/linaro-ubuntu/lava-test-lttng"]
+BZR_REPOS=["lp:~linaro-foundations/linaro-ubuntu/lava-test-lttng"]
+INSTALLSTEPS = ["apt-get build-dep lttng-tools --yes"]
 DEPS = ["bzr", "linux-headers-$(uname -r)", "lttng-modules-dkms"]
 RUNSTEPS = ["cd lava-test-lttng; sudo bash -x ./run-test.sh"]
 PATTERN = "^(?P<test_case_id>[\w:()]+)\s+\-\s+(?P<result>\w+$)"
 
-installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
+installer = TestInstaller(INSTALLSTEPS, deps=DEPS, bzr_repos=BZR_REPOS)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parser = TestParser(PATTERN)
 
