@@ -57,7 +57,7 @@ PATTERN = (
 
 installer = TestInstaller(INSTALLSTEPS, deps=DEPS, git_repos=GIT_REPOS)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
-parser = TestParser(PATTERN, appendall={'result': 'pass'})
+parser = TestParser(PATTERN)
 
 testobj = Test(
     test_id="pwrmgmt",
